import sys
import os
import shutil
import datetime
import numpy as np
'''
usage: python Simulation_Outputs_processing_for_BayesTraits.py [full path to directory with simulation data]

The point of this script is to convert the simulated multistate discrete character data 
into binary trait format for BayesTraits analyses.  This script is very specific to my 
data set due to the number of characters included for each trait (adult ecol: 3 states,
oviposition: 4 states, water: 2 states, repro mode: 4 states), but you could try your
luck to modify it. The basic principle is to randomly take a state for each of the two 
traits of interest, thereby allowing many different comparison combinations. Because the 
point of these simulations is to see how often independent characters are recovered as 
correlated, doing it this way seems the best (rather than always choosing state 1 of character
A and state 1 of character B, for example).  I tested three trait combinations.

The script will generate 500 binary trait files per trait combination and move these to
the appropriate directory. Creates directories "ecol_ovi", "ecol_water", and 
"ovi_water" in the path to the simulated data provided.

############################################
Written for Python 2.7.3
External Dependencies: Numpy (Numerical Python)
############################################

Dan Portik
daniel.portik@uta.edu
February 2016
'''

#get sim dir
sim_dir = sys.argv[1]
os.chdir(sim_dir)

out_dir1 = "ecol_ovi"
if not os.path.exists(out_dir1):
    os.mkdir(out_dir1)
out_dir2 = "ecol_water"
if not os.path.exists(out_dir2):
    os.mkdir(out_dir2)
out_dir3 = "ovi_water"
if not os.path.exists(out_dir3):
    os.mkdir(out_dir3)
    
sim_list = []

for filetype in os.listdir('.'):
    if filetype.endswith('txt'):
        names = filetype.split('_')
        sim_list.append(names[1])

sim_list.sort(key = len, reverse = True)
print sim_list
    
for sim in sim_list:
    for filetype in os.listdir('.'):
        if os.path.isfile(filetype) and filetype.endswith('.txt'):
            split = filetype.split("_")
            if split[1] == sim:
                fh_temp = open(filetype, 'r')
                lines = fh_temp.readlines()
                #col 1 = adult ecol (3 states)
                #col 2 = oviposition (4 states)
                #col 3 = water (2 states)
                #col 4 = repro mode (4 states)
                
                rando1 = int((np.random.choice(3, 1))+1)
                rando2 = int((np.random.choice(4, 1))+1)
                rando3 = int((np.random.choice(2, 1))+1)
                print "Parsing {0} using {1}, {2}, and {3}".format(filetype,rando1, rando2, rando3)
                out1 = "ecol_ovi_{}.txt".format(sim)
                fh_ecol = open(out1, 'a')
                out2 = "ecol_water_{}.txt".format(sim)
                fh_water = open(out2, 'a')
                out3 = "ovi_water_{}.txt".format(sim)
                fh_ovi = open(out3, 'a')

                for line in lines[1:]:
                    line = line.strip()
                    line = line.split('\t')
                    taxon = line[0]
                    ecol = line[1]
                    ovi = line[2]
                    water = line[3]
                    repro = line[4]
                    
                    #ecol_ovi
                    fh_ecol.write(taxon+'\t')
                    if int(ecol) == int(rando1):
                        fh_ecol.write("1"+'\t')
                    elif int(ecol) != int(rando1):
                        fh_ecol.write("0"+'\t')
                    if int(ovi) == int(rando2):
                        fh_ecol.write("1"+'\n')
                    elif int(ovi) != int(rando2):
                        fh_ecol.write("0"+'\n')
                            
                    #ecol_water
                    fh_water.write(taxon+'\t')
                    if int(ecol) == int(rando1):
                        fh_water.write("1"+'\t')
                    elif int(ecol) != int(rando1):
                        fh_water.write("0"+'\t')
                    if int(water) == int(rando3):
                        fh_water.write("1"+'\n')
                    elif int(water) != int(rando3):
                        fh_water.write("0"+'\n')
                            
                    #ovi_water
                    fh_ovi.write(taxon+'\t')
                    if int(ovi) == int(rando2):
                        fh_ovi.write("1"+'\t')
                    elif int(ovi) != int(rando2):
                        fh_ovi.write("0"+'\t')
                    if int(water) == int(rando3):
                        fh_ovi.write("1"+'\n')
                    elif int(water) != int(rando3):
                        fh_ovi.write("0"+'\n')
                 
                fh_ecol.close()
                fh_water.close()
                fh_ovi.close()
                fh_temp.close()
                
                shutil.move(out1, out_dir1)
                shutil.move(out2, out_dir2)
                shutil.move(out3, out_dir3)
